@@ -4,4 +4,7 @@ from msdm.algorithms.lrtdp import LRTDP
 from msdm.algorithms.policyiteration import PolicyIteration
 from msdm.algorithms.search import BreadthFirstSearch, AStarSearch
 from msdm.algorithms.entregpolicyiteration import EntropyRegularizedPolicyIteration
+from msdm.algorithms.pointbasedvalueiteration import PointBasedValueIteration
+from msdm.algorithms.qmdp import QMDP
+from msdm.algorithms.fscgradientascent import FSCGradientAscent
 from msdm.algorithms.tdlearning import QLearning, SARSA, ExpectedSARSA, DoubleQLearning
