@@ -1,9 +1,14 @@
 from msdm.core.distributions.distributions import FiniteDistribution
+from collections import defaultdict
 import random
 
 
 class UniformDistribution(FiniteDistribution):
-    def __init__(self, support):
+    def __init__(self, support, check_unique=True):
+        if check_unique:
+            assert len(support) == len(set(support)), (
+                f'Invalid support {support}: some event is duplicated.'
+            )
         self._support = support
     @property
     def support(self):
@@ -30,7 +35,7 @@ class DeterministicDistribution(FiniteDistribution):
     def items(self):
         yield self.value, 1
 
-class DictDistribution(FiniteDistribution,dict):
+class DictDistribution(dict,FiniteDistribution):
     @classmethod
     def uniform(cls, support):
         return UniformDistribution(support)
@@ -39,9 +44,24 @@ class DictDistribution(FiniteDistribution,dict):
     def deterministic(cls, element):
         return DeterministicDistribution(element)
 
+    @classmethod
+    def from_pairs(cls, element_probs):
+        dist = defaultdict(float)
+        for e, p in element_probs:
+            dist[e] += p
+        return DictDistribution(dist)
+
     @property
     def support(self):
         return self.keys()
 
     def prob(self, e):
         return self.get(e, 0.0)
+
+    items = dict.items
+    values = dict.values
+    __or__ = FiniteDistribution.__or__
+    __and__ = FiniteDistribution.__and__
+    __mul__ = FiniteDistribution.__mul__
+    __rmul__ = FiniteDistribution.__rmul__
+    __repr__ = FiniteDistribution.__repr__
